@@ -7,10 +7,12 @@ from .stream import Stream
 
 
 class Parser:  # mb: we don't need Parser itself. its just storage for links and tags. Hm...
-    def __init__(self, implicit_fstrings: bool = True):
+    def __init__(self, implicit_fstrings: bool = True,
+                 strict: bool = False):
         self.links = []
         self.iterators = []
         self.implicit_fstrings = implicit_fstrings
+        self.strict = strict
         self.last_indent = -1
 
     def parse(self, path: Union[str, Path]):
@@ -38,4 +40,4 @@ class ParserError(Exception):  # ToDo: currently blank lines skipped thus printe
         self.msg = msg
 
     def __str__(self):
-        return f"{self.line}:{self.pos}: {self.msg}"
+        return f"{self.line + 1}:{self.pos}: {self.msg}"
