@@ -10,7 +10,8 @@ class Stream:
         self.n = 0
         self.pos = 0
 
-    def peek(self, *args: Union[tokens.Token, Type[tokens.Token]]):  # read several tokens from stream
+    def peek(self, *args: Union[tokens.Token, Type[tokens.Token]]):
+        """Reads several tokens from stream"""
         if not self:
             return None
         line = self.lines[self.n]
